<?php

namespace Drupal\carousel_block;

use Drupal\Core\Entity\Sql\SqlContentEntityStorage;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Language\LanguageInterface;
use Drupal\carousel_block\Entity\CarouselEntityInterface;

/**
 * Defines the storage handler class for Carousel entity entities.
 *
 * This extends the base storage class, adding required special handling for
 * Carousel entity entities.
 *
 * @ingroup carousel_block
 */
class CarouselEntityStorage extends SqlContentEntityStorage implements CarouselEntityStorageInterface {

  /**
   * {@inheritdoc}
   */
  public function revisionIds(CarouselEntityInterface $entity) {
    return $this->database->query(
      'SELECT vid FROM {carousel_entity_revision} WHERE id=:id ORDER BY vid',
      [':id' => $entity->id()]
    )->fetchCol();
  }

  /**
   * {@inheritdoc}
   */
  public function userRevisionIds(AccountInterface $account) {
    return $this->database->query(
      'SELECT vid FROM {carousel_entity_field_revision} WHERE uid = :uid ORDER BY vid',
      [':uid' => $account->id()]
    )->fetchCol();
  }

  /**
   * {@inheritdoc}
   */
  public function countDefaultLanguageRevisions(CarouselEntityInterface $entity) {
    return $this->database->query('SELECT COUNT(*) FROM {carousel_entity_field_revision} WHERE id = :id AND default_langcode = 1', [':id' => $entity->id()])
      ->fetchField();
  }

  /**
   * {@inheritdoc}
   */
  public function clearRevisionsLanguage(LanguageInterface $language) {
    return $this->database->update('carousel_entity_revision')
      ->fields(['langcode' => LanguageInterface::LANGCODE_NOT_SPECIFIED])
      ->condition('langcode', $language->getId())
      ->execute();
  }

}
